Learn R Programming

tcsinvest (version 0.1.1)

sandboxRegister: Working with sandbox. Register account

Description

Register sandbox account

Usage

sandboxRegister(token = "")

Arguments

token

token from Tinkoff account (only sandbox token)

Value

returns a list object containing the information about state of operation.

Details

If you need to create few money position, use this function for each position

See Also

sandboxDeleteAccount

Examples

Run this code
# NOT RUN {
token = 'your_token_from_tcs_account'
sandboxRegister(token)
# }

Run the code above in your browser using DataLab