powered by
Register sandbox account
sandboxRegister(token = "")
token from Tinkoff account (only sandbox token)
returns a list object containing the information about state of operation.
If you need to create few money position, use this function for each position
sandboxDeleteAccount
# NOT RUN { token = 'your_token_from_tcs_account' sandboxRegister(token) # }
Run the code above in your browser using DataLab